@@ -181,7 +181,7 @@ class SyncroReportWeeklyCreator(FrigelReportCreator):
         
         
     def __add_working_modes_data(self):
-        data_pie = [np.sum(self.working_modes_hours[mode]) for mode in WORKING_MODE_TYPES]
+        data_pie = [np.sum(0 if x is None else x for x in self.working_modes_hours[mode]) for mode in WORKING_MODE_TYPES]
         pie_working_modes = PieChartWorkingModes(data=data_pie,
                                                  data_trend=self.working_modes_trend,
                                                  header_names=(self.translations.getTranslation('Phases'), 
